@@ -9,6 +9,9 @@ var Presentation = {
         this.deck     = document.getElementById('deck');
         this.scroller = document.getElementById('scroller');
 
+               this.canvas.appendChild(document.createElement('description'));
+               this.canvas.lastChild.setAttribute('id', "caption");
+               this.canvas.lastChild.setAttribute('class', 'subtitle');
         this.toolbar         = document.getElementById('canvasToolbar');
         this.toolbarHeight   = this.toolbar.boxObject.height;
         this.isToolbarHidden = true;
@@ -82,14 +85,20 @@ var Presentation = {
             line = text[i];
             image_width  = 0;
             image_height = 0;
+            var subtitle = '';
+
+            if (line.match(/^~/)) {
+              subtitle = line.substring(1);
+              line = '';
+            }
+
 
             if (line.match(/^ /)) {
               code_listing = 1; 
               this.content.lastChild.setAttribute('align', 'left');
               this.content.lastChild.setAttribute('class', 'pre');
               line = line.substring(1)
-            }
-
+            } 
             while (line.match(/^([^\{]+)?(\{\{ima?ge? +src="([^"]+)" +width="([0-9]+)" +height="([0-9]+)"[^\}]*\}\}|\{\{(([^\|]+)?\||)([^\}]+)\}\})(.+)?/))
             {
                 if (RegExp.$1) {
@@ -147,6 +156,13 @@ var Presentation = {
         }
 
         this.content.setAttribute('style', 'font-size:10px;');
+          caption =  document.getElementById('caption');
+        if (subtitle) {
+               caption.setAttribute('value', subtitle);
+        } else {
+               caption.setAttribute('value', '');
+
+        }
 
         if (this.content.boxObject.width) {
             var canvas_w  = this.canvas.boxObject.width;
@@ -158,7 +174,7 @@ var Presentation = {
             if (new_fs > 32) {
                 new_fs = new_fs - (new_fs % 32) 
             }
-            if (code_listing) { new_fs = 48;}
+            //if (code_listing) { new_fs = 48;}
 
             this.content.setAttribute('style', 'top: 0');
             this.content.setAttribute('style', 'font-size:'+ new_fs + "px");
@@ -170,15 +186,12 @@ var Presentation = {
             }
 
             var content_h = this.content.boxObject.height;
-            if(content_h >= canvas_h){
-                content_h = this.content.boxObject.height;
-                new_fs = Math.round((canvas_h/content_h) * new_fs);
+            if(content_h >= (canvas_h - 70)){ // That 50 is space for subtitles
+                new_fs = Math.round(((canvas_h-70)/content_h) * new_fs);
                 this.content.setAttribute('style', 'font-size:'+ new_fs + "px");
+                content_h = this.content.boxObject.height;
             }
         }
-
-
-
         this.canvas.removeAttribute('rendering');
     },
 
