@@ -58,9 +58,6 @@ sub take_action {
 
     my %values;
     for (grep { defined $self->argument_value($_) } $self->argument_names) {
-        # Skip nonexistent fields
-        next unless $self->record->column($_);
-
         $values{$_} = $self->argument_value($_);
         if (ref $values{$_} eq "Fh") { # CGI.pm's "lightweight filehandle class"
             local $/;
@@ -74,8 +71,8 @@ sub take_action {
 
     # Handle errors?
     unless ( $record->id ) {
-        $self->result->error("An error occurred.  Try again later");
-        $self->log->error("Create of ".ref($record)." failed: $msg");
+        $self->result->error(_("An error occurred.  Try again later"));
+        $self->log->error(_("Create of %1 failed: %2", ref($record), $msg));
         return;
     }
 
@@ -87,19 +84,6 @@ sub take_action {
     return 1;
 }
 
-=head2 possible_fields
-
-Returns all of the columns on the record class.  This is because,
-unlike L<Jifty::Action::Record::Update>, columns which are marked as
-'immutable' should still be able to be set at creation time.
-
-=cut
-
-sub possible_fields {
-    my $self = shift;
-    return map {$_->name} grep {$_->type ne "serial"} $self->record->columns;
-}
-
 =head2 report_success
 
 Sets the L<Jifty::Result/message> to default success message,
