@@ -54,6 +54,13 @@ sub new {
     Jifty::ClassLoader->new(base => $class)->require;
     Jifty::Util->require($class->dispatcher);
 
+    # Start a plugin classloader set up on behalf of the application
+    require Jifty::Plugin::ClassLoader;
+    Jifty::Plugin::ClassLoader->new(
+	base => Jifty->config->framework('ApplicationClass'),
+	plugin => $class,
+    )->require;
+
     # XXX TODO: Add .po path
 
     my $self = bless {} => $class;
