@@ -6,7 +6,7 @@ use base qw/Jifty::Notification Jifty::Plugin::Login/;
 
 =head1 NAME
 
-Jifty::Plugin::Login::Notification::ConfirmAddress
+Hiveminder::Notification::ConfirmAddress
 
 =head1 ARGUMENTS
 
@@ -36,19 +36,20 @@ sub setup {
     my $confirm_url = $letme->as_url;
     my $appname = Jifty->config->framework('ApplicationName');
 
-    $self->subject( _("Welcome to ")."$appname!" );
+    $self->subject( "Welcome to $appname!" );
     $self->from( Jifty->config->framework('AdminEmail') );
 
-    $self->body(_("
-You're getting this message because you (or somebody claiming to be you)
-signed up for %1.
+    $self->body(<<"END_BODY");
 
-Before you can use %1, we need to make sure that we got your email
+You're getting this message because you (or somebody claiming to be you)
+signed up for $appname.
+
+Before you can use $appname, we need to make sure that we got your email
 address right.  Click on the link below to get started:
 
-%2
-",$appname,$confirm_url));
+$confirm_url
 
+END_BODY
 }
 
 1;
