@@ -74,7 +74,6 @@ Autocompleter.Base.prototype = {
 
     Element.hide(this.update);
 
-    Event.observe(this.element, "focus", this.onFocus.bindAsEventListener(this));
     Event.observe(this.element, "blur", this.onBlur.bindAsEventListener(this));
     Event.observe(this.element, "keypress", this.onKeyPress.bindAsEventListener(this));
   },
@@ -177,16 +176,6 @@ Autocompleter.Base.prototype = {
     this.active = false;     
   },
 
-  onFocus: function(event) {
-    this.changed = true;
-    this.hasFocus = true;
-
-    if (this.observer)
-        clearTimeout(this.observer);
-    
-    this.onObserverEvent();
-  },
-  
   render: function() {
     if(this.entryCount > 0) {
       for (var i = 0; i < this.entryCount; i++)
